@@ -47,12 +47,12 @@ class Config:
 
     def get(self):
         if self.CONFIG_FILE.exists():
-            return pickle.load(self.CONFIG_FILE.open('rb'))
+            return pickle.load(self.CONFIG_FILE.open('rb', encoding='utf-8'))
         else:
             return {}
 
     def put(self, config):
-        pickle.dump(config, self.CONFIG_FILE.open('wb'))
+        pickle.dump(config, self.CONFIG_FILE.open('wb', encoding='utf-8'))
 
 
 class Tapd:
@@ -232,7 +232,7 @@ class BVTCases(Cases):
         # 插入 task_id 列至最后
         task_id_cell = self.case_ws.cell(2, self.case_ws.max_column + 1, 'task_id')
 
-        template = Template(BVT_TASK_TEMPLATE.read_text())
+        template = Template(BVT_TASK_TEMPLATE.read_text(encoding='utf-8'))
         stories_map = self.iteration_meta_info.get('iteration_stories', {})
 
         # self.excel.tapd.create_tapd_task = lambda *args, **kwargs: time.sleep(1)
